@@ -1,11 +1,12 @@
 package Vimana::Installer::Vimball;
 use warnings;
 use strict;
-use parent qw(Vimana::Installer);
+use base qw(Vimana::Installer);
 use File::Temp qw(tempfile);
 use Vimana::Util;
 use Vimana::Logger;
 use Vimana::Record;
+use Vimana::VimballInstall;
 
 sub scan_vimball {
     my ($self,$file) = @_;
